﻿using Steema.TeeChart.WPF;
using System;
using System.Collections.Generic;
using System.Windows;
using System.Windows.Media;

namespace WpfAppTeechart
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        TChart tChart1 = new TChart();
        public MainWindow()
        {
            InitializeComponent();            

            tChart1.Legend.Visible = false;
            tChart1.Aspect.View3D = false;

            tChart1.Panel.MarginLeft = 1;
            tChart1.Panel.MarginRight = 1;
            tChart1.Panel.MarginTop = 10;
            tChart1.ClipToBounds = true;
            tChart1.Aspect.ClipPoints = true;

            UpdateTeechartBasicSettings();
            UpdateTeeChartDisplaySetting();
            FillTeeChartSeriesDataDesignTime();


            this.grid1.Children.Add(tChart1);
            
        }

        private void SetPanelMargin()
        {
            tChart1.Panel.MarginLeft = 21;
            tChart1.Panel.MarginRight = 3;
        }

        void FillTeeChartSeriesDataDesignTime()
        {

            Random rnd = new Random();
            int AxisIndex = 0;

            if (tChart1 != null)
            {
                if (tChart1.Series.Count > 0)
                    tChart1.Series.RemoveAllSeries();

                if (tChart1.Axes.Custom.Count > 0)
                    tChart1.Axes.Custom.RemoveAll();

                SetPanelMargin();

                //MessageBox.Show("FillTeeChartSeriesDataDesignTime");

                
                for (int ip=1;ip<4;ip++)
                {

                    Steema.TeeChart.WPF.Styles.Line line1 = new Steema.TeeChart.WPF.Styles.Line(tChart1.Chart);
                    UpdateSeriesConfiguration(line1);

                    line1.Add(1, 1);
                    for (int j = 2; j <= 28; ++j)
                    {
                        line1.Add(j, j + AxisIndex * 4);
                    }

                    bool drawYAxis = true;
                    CreateAxis(tChart1[AxisIndex], AxisIndex, drawYAxis, ip);

                    AxisIndex++;
                }
            }
        }

        private double relativePositionInterval = -10;

        private void CreateAxis(Steema.TeeChart.WPF.Styles.Series s, int pos, bool drawYAxis, int axisIndex)
        {
            try
            {
                Axis axis = new Axis(false, false, tChart1.Chart);
                axis.RelativePosition = relativePositionInterval * (axisIndex);

                axis.StartPosition = 1;
                axis.EndPosition = 100;     //we cannot set this to 200 as it is a % value.

                axis.Visible = true;

                axis.Increment = 10;

                axis.AxisPen.Color = Colors.PowderBlue; //s.Color;
                axis.AxisPen.Style = (DashStyle)(typeof(DashStyles).GetProperty("Solid")).GetValue(null, null);
                axis.AxisPen.Visible = true;


                axis.Labels.ValueFormat = "#,##0";
                axis.Labels.Font.Color = axis.AxisPen.Color;
                axis.Labels.Angle = 90;
                axis.Labels.Visible = true;

                axis.Ticks.Color = axis.AxisPen.Color;
                axis.Ticks.Visible = true;

                axis.Grid.Visible = true;

                axis.MinorTicks.Color = axis.AxisPen.Color;
                axis.MinorTickCount = 4;
                axis.MinorTicks.Visible = true;

                axis.Automatic = false;

                double MinXValue = s.YValues.Maximum;
                double MinYValue = s.YValues.Minimum;

                if (MinXValue == MinYValue)
                {
                    axis.Minimum = MinXValue - MinXValue / 2;
                    axis.Maximum = MinYValue + MinYValue / 2;
                }
                else
                {
                    axis.Minimum = s.MinYValue();//Convert.ToInt16(s.MinYValue());
                    axis.Maximum = s.MaxYValue(); //Convert.ToInt16(s.MaxYValue());
                }

                if (true) //if (pds.YAxisMinimumValue == 1 && pds.YAxisMaximumValue == 28)
                {
                    axis.Minimum = 60;
                    axis.Maximum = 110;
                }


                axis.Visible = true;



                if (true)
                {


                    double diff = axis.Maximum - axis.Minimum;
                    //double axisHeight = (double)((tChart1.Chart.ChartRect.Height == 0) ? 0 : Math.Round((decimal)(diff / (tChart1.Chart.ChartRect.Height / 22)), pds.YAxisDecimalPoint)); //10; //diff / 10;
                    double axisIncrement = (double)Math.Round((decimal)(diff / 10), 0);

                    //double inc = Math.Round(Math.Max(this.GraphYAxisLabelFontSize * 1.5, Math.Max(pds.YAxisMajorScaleInterval, Math.Max(axisHeight, axisIncrement))));
                    double inc = Math.Max(10, axisIncrement);
                    if (inc > 0)
                    {
                        axis.Labels.Items.Clear();
                        for (decimal i = (decimal)axis.Minimum; i < (decimal)(axis.Maximum + inc); i += (decimal)inc)
                        {
                            AxisLabelItem axisLabelItem = new AxisLabelItem(tChart1.Chart);

                            if ((double)i < axis.Maximum)
                            {
                                axisLabelItem.Value = (double)i;
                                axisLabelItem.Text = DisplayNDecimal((double)i, 0);
                            }
                            else
                            {
                                axisLabelItem.Value = axis.Maximum;
                                axisLabelItem.Text = DisplayNDecimal(axis.Maximum, 0);
                            }
                            axisLabelItem.Font.Color = axis.AxisPen.Color;
                            axisLabelItem.Visible = true;
                            axisLabelItem.Font.Size = 11;
                            axisLabelItem.Font.Name = "Tahoma";
                            axisLabelItem.Transparent = true;
                            axisLabelItem.Font.Italic = false;
                            axisLabelItem.Font.Bold = false;
                            
                            axis.Labels.Items.Add(axisLabelItem);

                        }
                    }
                }

                // setting font details
                axis.Labels.Font.Size = 11;
                axis.Labels.Font.Name = "Tahoma";
                axis.Labels.Font.Italic = false;
                axis.Labels.Font.Bold = false;
                tChart1.Axes.Custom.Add(axis);
                s.CustomVertAxis = axis;
            }
            catch (TeeChartException ex)
            {
                //ignoring the msg
            }

        }

        private void UpdateSeriesConfiguration(Steema.TeeChart.WPF.Styles.CustomPoint customPoint)
        {
            customPoint.Tag = "ASDF";
            customPoint.Title = "BlahBlah";


            customPoint.Color = Colors.Pink;
            customPoint.Visible = true;

            customPoint.LinePen.Style = (DashStyle)(typeof(DashStyles).GetProperty("Solid")).GetValue(null, null);
            customPoint.LinePen.Width = 2;
            customPoint.LinePen.Visible = true;

            customPoint.Pointer.Pen.Color = Colors.Pink;
            customPoint.Pointer.Pen.Transparency = 100;
            customPoint.Pointer.Pen.Visible = false;
            customPoint.Pointer.Brush.Visible = false;

            //customPoint.Pointer.Style = (Steema.TeeChart.WPF.Styles.PointerStyles)Enum.Parse(typeof(Steema.TeeChart.WPF.Styles.PointerStyles), (graphDataSeries.Marker).ToString());
            customPoint.Pointer.Style = (Steema.TeeChart.WPF.Styles.PointerStyles)6;
            customPoint.Pointer.Color = Colors.Plum;
            customPoint.Pointer.HorizSize = 1;
            customPoint.Pointer.VertSize = 1;
            customPoint.Pointer.Transparency = 0;
            customPoint.Pointer.Visible = false;

            customPoint.Pointer.BitmapEffects = null;

        }

        private void UpdateTeechartBasicSettings()
        {
            try
            {
                if (tChart1 != null)
                {
                    tChart1.Axes.Bottom.Labels.Items.Clear();
                    tChart1.Zoom.History = true;
                    tChart1.Header.Text = "Hello";

                    tChart1.Axes.Bottom.StartPosition = 0;
                    tChart1.Axes.Bottom.EndPosition = 100;

                    tChart1.Axes.Bottom.Title.Caption = "Hello2";
                    tChart1.Axes.Bottom.Title.Visible = true;

                    tChart1.Axes.Bottom.Visible = true;

                    tChart1.Axes.Bottom.AutomaticMaximum = false;
                    tChart1.Axes.Bottom.AutomaticMinimum = false;

                    tChart1.Axes.Bottom.Labels.Angle = 0;   // GraphUtility.LabelOrientation[GraphDataSeriesCollection.XAxisOrientation];
                    tChart1.Axes.Bottom.OtherSide = false; //GraphUtility.XAxisPosition[GraphDataSeriesCollection.XAxisPosition];
                    tChart1.Axes.Bottom.Maximum = 1;
                    tChart1.Axes.Bottom.Minimum = 0;

                    tChart1.Axes.Bottom.Ticks.Visible = true;
                    tChart1.Axes.Bottom.MinorTicks.Visible = true;
                    tChart1.Axes.Bottom.MinorTickCount = 0;
                    tChart1.Axes.Bottom.Grid.Visible = true;
                    tChart1.Axes.Bottom.Labels.ValueFormat = "0.0";

                    //tChart1.Axes.Bottom.MinAxisIncrement = (tChart1.Axes.Bottom.Maximum - tChart1.Axes.Bottom.Minimum) / (GraphDataConfiguration.XAxisMajorScaleInterval + 1);
                    //tChart1.Axes.Bottom.Increment = (tChart1.Axes.Bottom.Maximum - tChart1.Axes.Bottom.Minimum) / (GraphDataConfiguration.XAxisMajorScaleInterval + 2);
                    tChart1.Axes.Bottom.Increment = 0.1;

                    //if (this.Panned == false)
                    {

                        tChart1.Axes.Bottom.Labels.Items.Clear();

                        double diff = tChart1.Axes.Bottom.Maximum - tChart1.Axes.Bottom.Minimum;
                        double axisHeight = (tChart1.Chart.ChartRect.Width == 0) ? 0 : Math.Round(diff / (tChart1.Chart.ChartRect.Width / 22)); //10; //diff / 10;
                        double axisIncrement = Math.Round(diff / 27);

                        //double inc = Math.Round(Math.Max(this.GraphYAxisLabelFontSize * 1.5, Math.Max(pds.YAxisMajorScaleInterval, Math.Max(axisHeight, axisIncrement))));
                        double inc = Math.Max(0.1, Math.Max(axisHeight, axisIncrement));

                        if (inc > 0)
                        {

                            for (decimal i = (decimal)tChart1.Axes.Bottom.Minimum; i < (decimal)(tChart1.Axes.Bottom.Maximum + inc); i += (decimal)inc)
                            {
                                if (((decimal)tChart1.Axes.Bottom.Maximum - i) >= (decimal)axisHeight || i >= (decimal)tChart1.Axes.Bottom.Maximum)//|| diff / inc < s.GetVertAxis.IAxisSize / this.GraphYAxisLabelFontSize * 1.5)
                                {
                                    AxisLabelItem axisLabelItem = new AxisLabelItem(tChart1.Chart);
                                    axisLabelItem.Value = Math.Min((double)i, tChart1.Axes.Bottom.Maximum);
                                    //axisLabelItem.Text = DisplayNDecimal(Math.Min((double)i, tChart1.Axes.Bottom.Maximum), 0);
                                    axisLabelItem.Text = DisplayNDecimal(Math.Min((double)i, tChart1.Axes.Bottom.Maximum), 1);
                                    axisLabelItem.Transparent = true;
                                    axisLabelItem.Font.Color = tChart1.Axes.Bottom.Labels.Font.Color; //this.Foreground as SolidColorBrush).Color;
                                    axisLabelItem.Visible = true;
                                    axisLabelItem.Font.Size = 11;
                                    axisLabelItem.Font.Name = "Tahoma";
                                    axisLabelItem.Font.Italic = false;
                                    axisLabelItem.Font.Bold = false;
                                    tChart1.Axes.Bottom.Labels.Items.Add(axisLabelItem);
                                }
                            }
                        }
                    }


                    //Setting Label Fonts
                    tChart1.Axes.Bottom.Labels.Font.Size = 11;
                    tChart1.Axes.Bottom.Labels.Font.Name = "Tahoma";


                    tChart1.Axes.Bottom.Labels.Font.Italic = false;
                    tChart1.Axes.Bottom.Labels.Font.Bold = false;



                    //Settings Title Font
                    tChart1.Axes.Bottom.Title.Font.Size = 11;
                    tChart1.Axes.Bottom.Title.Font.Name = "Tahoma";

                    tChart1.Axes.Bottom.Title.Font.Italic = false;
                    tChart1.Axes.Bottom.Title.Font.Bold = false;

                    //Settings Header Font
                    tChart1.Header.Font.Size = 11;
                    tChart1.Header.Font.Name = "Tahoma";

                    tChart1.Header.Font.Italic = false;                   

                    tChart1.Header.Font.Bold = false;

                   

                }
            }
            catch (TeeChartException e)
            {
                //ignore the msg
            }
        }

        public string DisplayNDecimal(double dbValue, int nDecimal)
        {
            return (dbValue.ToString("N" + nDecimal));
        }

        private void UpdateTeeChartDisplaySetting()
        {
            if (tChart1 != null)
            {

                tChart1.Walls.Back.Brush.Gradient.Visible = false;
                this.tChart1.Walls.Back.Transparent = true;

                this.tChart1.Panel.Gradient.Visible = false;
                this.tChart1.Panel.Transparent = true;


                if (this.Foreground is SolidColorBrush)
                {
                    this.tChart1.Axes.Bottom.Labels.Font.Color = (this.Foreground as SolidColorBrush).Color;
                    this.tChart1.Axes.Bottom.Title.Font.Color = (this.Foreground as SolidColorBrush).Color;
                    this.tChart1.Header.Font.Color = (this.Foreground as SolidColorBrush).Color;
                    

                    foreach (AxisLabelItem axisLabelItem in this.tChart1.Axes.Bottom.Labels.Items)
                    {
                        axisLabelItem.Font.Color = (this.Foreground as SolidColorBrush).Color;
                    }

                }
                else
                {
                    this.tChart1.Axes.Bottom.Labels.Font.Brush.Color = Colors.Black;
                    this.tChart1.Axes.Bottom.Title.Font.Color = Colors.Black;
                    this.tChart1.Header.Font.Color = Colors.Black;
                    

                    foreach (AxisLabelItem axisLabelItem in this.tChart1.Axes.Bottom.Labels.Items)
                    {
                        axisLabelItem.Font.Color = Colors.Black;
                    }
                }
            }
        }

    }
}
